// Copyright (c) Jupyter Development Team.
// Distributed under the terms of the Modified BSD License.
"use strict";
var default_1 = require('./default');
/**
 * A namespace for session interfaces and factory functions.
 */
var Session;
(function (Session) {
    /**
     * List the running sessions.
     *
     * #### Notes
     * Uses the [Jupyter Notebook API](http://petstore.swagger.io/?url=https://raw.githubusercontent.com/jupyter/notebook/master/notebook/services/api/api.yaml#!/sessions), and validates the response.
     *
     * All client-side sessions are updated with current information.
     *
     * The promise is fulfilled on a valid response and rejected otherwise.
     */
    function listRunning(options) {
        return default_1.DefaultSession.listRunning(options);
    }
    Session.listRunning = listRunning;
    /**
     * Start a new session.
     *
     * #### Notes
     * Uses the [Jupyter Notebook API](http://petstore.swagger.io/?url=https://raw.githubusercontent.com/jupyter/notebook/master/notebook/services/api/api.yaml#!/sessions), and validates the response.
     *
     * A path must be provided.  If a kernel id is given, it will
     * connect to an existing kernel.  If no kernel id or name is given,
     * the server will start the default kernel type.
     *
     * The promise is fulfilled on a valid response and rejected otherwise.
     *
     * Wrap the result in an Session object. The promise is fulfilled
     * when the session is created on the server, otherwise the promise is
     * rejected.
     */
    function startNew(options) {
        return default_1.DefaultSession.startNew(options);
    }
    Session.startNew = startNew;
    /**
     * Find a session by id.
     *
     * #### Notes
     * If the session was already started via `startNewSession`, the existing
     * Session object's information is used in the fulfillment value.
     *
     * Otherwise, if `options` are given, we attempt to find to the existing
     * session.
     * The promise is fulfilled when the session is found,
     * otherwise the promise is rejected.
     */
    function findById(id, options) {
        return default_1.DefaultSession.findById(id, options);
    }
    Session.findById = findById;
    /**
     * Find a session by path.
     *
     * #### Notes
     * If the session was already started via `startNewSession`, the existing
     * Session object's info is used in the fulfillment value.
     *
     * Otherwise, if `options` are given, we attempt to find to the existing
     * session using [listRunningSessions].
     * The promise is fulfilled when the session is found,
     * otherwise the promise is rejected.
     *
     * If the session was not already started and no `options` are given,
     * the promise is rejected.
     */
    function findByPath(path, options) {
        return default_1.DefaultSession.findByPath(path, options);
    }
    Session.findByPath = findByPath;
    /**
     * Connect to a running session.
     *
     * #### Notes
     * If the session was already started via `startNewSession`, the existing
     * Session object is used as the fulfillment value.
     *
     * Otherwise, if `options` are given, we attempt to connect to the existing
     * session.
     * The promise is fulfilled when the session is ready on the server,
     * otherwise the promise is rejected.
     *
     * If the session was not already started and no `options` are given,
     * the promise is rejected.
     */
    function connectTo(id, options) {
        return default_1.DefaultSession.connectTo(id, options);
    }
    Session.connectTo = connectTo;
    /**
     * Shut down a session by id.
     */
    function shutdown(id, options) {
        if (options === void 0) { options = {}; }
        return default_1.DefaultSession.shutdown(id, options);
    }
    Session.shutdown = shutdown;
})(Session = exports.Session || (exports.Session = {}));
