// Copyright (c) Jupyter Development Team.
// Distributed under the terms of the Modified BSD License.
"use strict";
var validate_1 = require('../kernel/validate');
/**
 * Validate a property as being on an object, and optionally
 * of a given type.
 */
function validateProperty(object, name, typeName) {
    if (!object.hasOwnProperty(name)) {
        throw Error("Missing property '" + name + "'");
    }
    if (typeName !== void 0) {
        var valid = true;
        var value = object[name];
        switch (typeName) {
            case 'array':
                valid = Array.isArray(value);
                break;
            case 'object':
                valid = typeof value !== 'undefined';
                break;
            default:
                valid = typeof value === typeName;
        }
        if (!valid) {
            throw new Error("Property '" + name + "' is not of type '" + typeName);
        }
    }
}
/**
 * Validate an `Session.IModel` object.
 */
function validateModel(model) {
    validateProperty(model, 'id', 'string');
    validateProperty(model, 'notebook', 'object');
    validateProperty(model, 'kernel', 'object');
    validate_1.validateModel(model.kernel);
    validateProperty(model.notebook, 'path', 'string');
}
exports.validateModel = validateModel;
